@@ -2,8 +2,8 @@
 
 using namespace Rcpp;
 
-#ifndef ERGMITO_H
-#define ERGMITO_H 1
+#ifndef ERGMITO_TYPES_H
+#define ERGMITO_TYPES_H 1
 
 typedef std::vector< int > vecint;
 typedef std::vector< std::vector< int > > vecvecint;
